==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ja/indian.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-thu-short-relative+0": "今週の木曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "翌週",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"field-year-narrow": "年",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "翌年",
	"field-tue-relative+1": "来週の火曜日",
	"field-second-short": "秒",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "翌週",
	"field-month-relative+1": "翌月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-month-short": "月",
	"field-day": "日",
	"field-year-relative+-1": "昨年",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"field-wed-relative+-1": "先週の水曜日",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"field-month": "月",
	"field-day-narrow": "日",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"eraAbbr": [
		"サカ"
	],
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "一昨日",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "前四半期",
	"field-week-narrow-relative+-1": "先週",
	"field-sat-relative+-1": "先週の土曜日",
	"field-hour": "時",
	"months-format-wide": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-month-relative+-1": "先月",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "翌月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"months-format-abbr": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"field-thu-short-relative+-1": "先週の木曜",
	"field-year-narrow-relative+-1": "昨年",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"field-wed-short-relative+0": "今週の水曜",
	"months-standAlone-wide": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-sat-relative+0": "今週の土曜日",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+1": "来週の土曜日",
	"field-day-short-relative+2": "明後日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "翌週",
	"months-standAlone-abbr": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "翌月",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"field-week": "週",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"field-year-short-relative+0": "今年",
	"field-year-short-relative+1": "翌年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"field-week-short-relative+-1": "先週",
	"field-hour-short": "時",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "翌年",
	"field-fri-relative+-1": "先週の金曜日",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "今週の月曜",
	"field-mon-narrow-relative+1": "来週の月曜",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"field-day-relative+-2": "一昨日",
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"field-fri-narrow-relative+1": "来週の金曜"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/ja/indian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "今四半期",
	"field-quarter-short-relative+1": "翌四半期",
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-thu-short-relative+0": "今週の木曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "来週",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"field-year-narrow": "年",
	"field-era-short": "時代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "来年",
	"field-tue-relative+1": "来週の火曜日",
	"field-weekdayOfMonth": "月の曜日番号",
	"field-second-short": "秒",
	"field-weekdayOfMonth-narrow": "月の曜日番号",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "来週",
	"field-month-relative+1": "来月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"サカ"
	],
	"field-weekOfMonth": "月の週番号",
	"field-month-short": "月",
	"field-day": "日",
	"field-dayOfYear-short": "年の通日",
	"field-year-relative+-1": "昨年",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"field-wed-relative+-1": "先週の水曜日",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"field-month": "月",
	"field-day-narrow": "日",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"eraAbbr": [
		"サカ"
	],
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "一昨日",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "前四半期",
	"field-dayperiod-narrow": "午前/午後",
	"field-week-narrow-relative+-1": "先週",
	"field-dayOfYear": "年の通日",
	"field-sat-relative+-1": "先週の土曜日",
	"field-hour": "時",
	"months-format-wide": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-month-relative+-1": "先月",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "来月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"field-quarter-short-relative+-1": "前四半期",
	"months-format-abbr": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"field-thu-short-relative+-1": "先週の木曜",
	"field-year-narrow-relative+-1": "昨年",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"field-weekOfMonth-short": "月の週番号",
	"field-wed-short-relative+0": "今週の水曜",
	"months-standAlone-wide": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-quarter-narrow-relative+0": "今四半期",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+0": "今週の土曜日",
	"field-quarter-narrow-relative+1": "翌四半期",
	"field-day-short-relative+2": "明後日",
	"field-sat-relative+1": "来週の土曜日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "来週",
	"months-standAlone-abbr": [
		"カイトラ",
		"ヴァイサカ",
		"ジャイスタ",
		"アーサダ",
		"スラバナ",
		"バードラ",
		"アスビナ",
		"カルディカ",
		"アヴラハヤナ",
		"パウサ",
		"マーガ",
		"パルグナ"
	],
	"field-dayOfYear-narrow": "通日",
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "来月",
	"field-weekdayOfMonth-short": "月の曜日番号",
	"field-zone-narrow": "タイムゾーン",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"field-week": "週",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"field-quarter-narrow-relative+-1": "前四半期",
	"field-year-short-relative+0": "今年",
	"field-dayperiod-short": "午前/午後",
	"field-year-short-relative+1": "来年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"field-week-short-relative+-1": "先週",
	"field-hour-short": "時",
	"field-zone-short": "タイムゾーン",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "来年",
	"field-era-narrow": "時代",
	"field-fri-relative+-1": "先週の金曜日",
	"eraNarrow": "サカ",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "今週の月曜",
	"field-mon-narrow-relative+1": "来週の月曜",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"field-weekOfMonth-narrow": "月の週番号",
	"field-weekday-narrow": "曜日",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"field-day-relative+-2": "一昨日",
	"field-weekday-short": "曜日",
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"field-fri-narrow-relative+1": "来週の金曜"
}
//end v1.x content
);
